==> gradle-9.3.0-20251024004622+0000-all.zip: gradle-9.3.0-20251024004622+0000/src/configuration-cache/org/gradle/internal/cc/impl/DefaultBuildToolingModelControllerFactory.kt <==
/*
 * Copyright 2021 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.internal.cc.impl

import org.gradle.internal.build.BuildLifecycleController
import org.gradle.internal.build.BuildState
import org.gradle.internal.build.BuildToolingModelController
import org.gradle.internal.build.BuildToolingModelControllerFactory
import org.gradle.internal.build.DefaultBuildToolingModelController
import org.gradle.internal.build.ResilientBuildToolingModelController
import org.gradle.internal.buildtree.BuildModelParameters
import org.gradle.tooling.provider.model.internal.ToolingModelBuilderLookup


internal
class DefaultBuildToolingModelControllerFactory(
    private val modelParameters: BuildModelParameters
) : BuildToolingModelControllerFactory {
    override fun createController(owner: BuildState, controller: BuildLifecycleController): BuildToolingModelController {
        val modelBuilderLookup = controller.gradle.services.get(ToolingModelBuilderLookup::class.java)
        val defaultController = if (modelParameters.isResilientModelBuilding) {
            ResilientBuildToolingModelController(owner, controller, modelBuilderLookup)
        } else {
            DefaultBuildToolingModelController(owner, controller, modelBuilderLookup)
        }
        return if (modelParameters.isIntermediateModelCache) {
            ConfigurationCacheAwareBuildToolingModelController(defaultController, controller.gradle.services.get(BuildTreeConfigurationCache::class.java))
        } else {
            defaultController
        }
    }
}

==> gradle-9.3.0-20251215012523+0000-all.zip: gradle-9.3.0-20251215012523+0000/src/configuration-cache/org/gradle/internal/cc/impl/DefaultBuildToolingModelControllerFactory.kt <==
/*
 * Copyright 2021 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.internal.cc.impl

import org.gradle.internal.build.BuildLifecycleController
import org.gradle.internal.build.BuildState
import org.gradle.internal.build.BuildToolingModelController
import org.gradle.internal.build.BuildToolingModelControllerFactory
import org.gradle.internal.build.DefaultBuildToolingModelController
import org.gradle.internal.build.ResilientBuildToolingModelController
import org.gradle.internal.buildtree.BuildModelParameters
import org.gradle.tooling.provider.model.internal.ToolingModelBuilderLookup


internal
class DefaultBuildToolingModelControllerFactory(
    private val modelParameters: BuildModelParameters
) : BuildToolingModelControllerFactory {
    override fun createController(owner: BuildState, lifecycleController: BuildLifecycleController): BuildToolingModelController {
        val modelBuilderLookup = lifecycleController.gradle.services.get(ToolingModelBuilderLookup::class.java)
        val toolingModelController = if (modelParameters.isResilientModelBuilding) {
            ResilientBuildToolingModelController(owner, lifecycleController, modelBuilderLookup)
        } else {
            DefaultBuildToolingModelController(owner, lifecycleController, modelBuilderLookup)
        }
        return if (modelParameters.isIntermediateModelCache) {
            ConfigurationCacheAwareBuildToolingModelController(toolingModelController, lifecycleController.gradle.services.get(BuildTreeConfigurationCache::class.java))
        } else {
            toolingModelController
        }
    }
}
